@@ -29,6 +29,10 @@
 #include <string.h>
 #include <math.h>
 
+#ifdef USE_DMALLOC
+#include <dmalloc.h>
+#endif
+
 /* own headers */
 #include "globals.h"
 #include "metro.h"
