@@ -28,6 +28,10 @@
 #include <stdlib.h>
 #include <math.h>
 
+#ifdef USE_DMALLOC
+#include <dmalloc.h>
+#endif
+
 /* own headers */
 #include "globals.h"
 #include "metro.h"
